@@ -5,12 +5,16 @@ from __future__ import print_function
 from typing import List
 
 import grpc
+from google.protobuf.json_format import MessageToDict
 from . import llm_embed_pb2
 from . import llm_embed_pb2_grpc
 
 def get_embeddings(stub, sentences):
     response = stub.Embed(sentences)
-    return response.reply
+    results = []
+    for message in response.embedding:
+        results.append(MessageToDict(message).get('feature'))
+    return results
 
 
 def run(
@@ -22,6 +26,4 @@ def run(
         sentences = llm_embed_pb2.Sentences(
             inputs=inputs,
         )
-        return [
-            get_embeddings(stub, sentences)
-        ]
+        return get_embeddings(stub, sentences)
