@@ -1,9 +1,10 @@
+from typing import List
 from dataclasses import dataclass
 
 @dataclass(unsafe_hash=True)
 class LanguageModel:
     def embed(self, 
         inputs: list=[],
-    ) -> str:
+    ) -> List[list]:
         # TODO : implement method for your LLM
-        return []
\ No newline at end of file
+        return [[]]
\ No newline at end of file
