@@ -18,14 +18,20 @@ class LanguageModelServicer(llm_embed_pb2_grpc.LanguageModelServicer):
         self.model = model
     
     def Embed(self, request, context):
-        predicted = self.model.embed(
+        embeddings = self.model.embed(
             inputs=request.inputs,
         )
-        return llm_embed_pb2.ListOfEmbeddings(reply=predicted)
+        grpc_embeddings = llm_embed_pb2.ListOfEmbeddings()
+        for embedding in embeddings:
+            grpc_embedding = llm_embed_pb2.Embedding()
+            for feature in embedding:
+                grpc_embedding.feature.append(feature)
+            grpc_embeddings.embedding.append(grpc_embedding)
+        return grpc_embeddings
 
 
-def serve(address='[::]:50051', model_servicer=LanguageModelServicer()):
-    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
+def serve(address='[::]:50051', model_servicer=LanguageModelServicer(), max_workers=10):
+    server = grpc.server(futures.ThreadPoolExecutor(max_workers=max_workers))
     llm_embed_pb2_grpc.add_LanguageModelServicer_to_server(
         model_servicer, server)
     server.add_insecure_port(address=address)
